* Export results to DINA(Distrib).xlsx

* external full PUF data
if $online == 0 {
	global diroutsheet "$root/output/ToExcel"
	global dirgraph	   "$diroutput/graphs"
	global diroutexcel "$root/DINA(distrib)External.xlsx"
	cap mkdir $dirgraph
	local last = $lastyear
}	

* internal IRS data, $online manually changed in runusdina.do
if $online == -1 {
	global diroutsheet "$root/output/ToExcelInternal"
	global dirgraph	   "$diroutput/graphsInternal"
	global diroutexcel "$root/DINA(distrib).xlsx"
	cap mkdir $dirgraph
	local last = $lastyear
}

* online small PUF data
if $online == 1 & $calibweight != 1 {
	global diroutsheet "$root/output/ToExcelonline"
	global dirgraph	   "$diroutput/graphsOnline"
	global diroutexcel "$root/DINA(distrib)Online.xlsx"
	cap mkdir $dirgraph
	local last = $lastyear
}	


* online small PUF data with calibrated weights
if $online == 1 & $calibweight == 1 {
	global diroutsheet "$root/output/ToExcelonlinecal"
	global dirgraph	   "$diroutput/graphsOnlinecal"
	global diroutexcel "$root/DINA(distrib)Onlinecal.xlsx"
	cap mkdir $dirgraph
	local last = $lastyear
}	



local population "indiv equal taxu  working male female" 
local variable "fiinc fninc princ peinc poinc hweal"
local agebin "99"

****************************************************************************************************************************************************************
*
* CREATE DATASET WITH YEARS IN ROW AND SHARES, THRESHOLDS, AND AVERAGES IN COLUMN
*
****************************************************************************************************************************************************************


* Deflators to compute real values
	qui import excel using "$parameters", firstrow clear 
		keep if yr<=`last'
		keep yr nideflator
		rename yr c1
	saveold $dirgraph/datagraph.dta, replace

* Bring Excel results 
	foreach pop of local population {
		foreach inc of local variable {
			foreach stat in compo  thres sh  { 
				foreach age of local agebin {
					capture {
						import excel "$diroutsheet/`stat'`inc'`pop'`age'.xlsx", first clear
							if "`stat'" == "compo" | "`stat'" == "sh" {
								foreach var of varlist *0 { // create *8 = bottom 50, *9 = bottom 90, and *10 = middle 40
									local j =substr("`var'",1,length("`var'")-1)
									gen `j'8 = `j'0 - `j'1
									gen `j'9 = `j'0 - `j'2
									gen `j'10 = `j'9 - `j'8									
								}								
								ds c1, not
								foreach var of varlist `r(varlist)' {
									rename `var' sh`var'`pop'`age'
								}	
							}
							if "`stat'" == "thres"  {
								keep c1 n total `inc'1  // keep median only for now
								rename `inc'1 thres`inc'1`pop'`age'
							}
						cap rename total m`inc'`pop'`age'
						cap rename n 	 p`inc'`pop'`age'
						merge 1:1 c1 using $dirgraph/datagraph.dta, update
						drop _merge
						saveold $dirgraph/datagraph.dta, replace
					}
				}	
			}
		}	
	}



* Smoothing shares and averages 1967-1978 (as in Saez-Zucman QJE 2016: real estate in small files is bumpy)
	use "$dirgraph/datagraph.dta", clear
	sort c1
	foreach var of varlist sh*  {
		qui replace `var' = (`var' + 0.5 * (`var'[_n-1] + `var'[_n+1])) / 2 if (c1 >= 1967 & c1 <= 1978) 
	}
	saveold $dirgraph/datagraph.dta, replace


* Create averages in avg`var'`i'`pop'`age' format 
	foreach pop of local population {
		foreach var of local variable {
				foreach age of local agebin {
					forval i = 0/10 {
						quietly {
						if `i' == 0 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (1 * p`var'`pop'`age')
						if `i' == 1 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.5 * p`var'`pop'`age')
						if `i' == 2 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.1 * p`var'`pop'`age')
						if `i' == 3 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.05 * p`var'`pop'`age')
						if `i' == 4 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.01 * p`var'`pop'`age')
						if `i' == 5 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.005 * p`var'`pop'`age')
						if `i' == 6 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.001 * p`var'`pop'`age')
						if `i' == 7 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.0001 * p`var'`pop'`age')
						if `i' == 8 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.5 * p`var'`pop'`age')
						if `i' == 9 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.9 * p`var'`pop'`age')
						if `i' == 10 cap gen avg`var'`i'`pop'`age' = sh`var'`i'`pop'`age' * m`var'`pop'`age' / (0.4 * p`var'`pop'`age')
						}
					}
				}
			}
		}	
	saveold $dirgraph/datagraph.dta, replace


* Bring pre-62 series
	use $dirgraph/datagraph.dta, clear
	rename c1 year
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta", update
	drop _merge
	saveold $dirgraph/datagraph.dta, replace


* Label variables
	forval i = 0/10 {
		foreach pop of local population {
			foreach inc of local variable {
				foreach stat in sh  thres   {
					foreach age of local agebin {
						if "`inc'" == "fiinc" cap label variable `stat'`inc'`i'`pop'`age' "Fiscal income (with KG)"
						if "`inc'" == "fninc" cap label variable `stat'`inc'`i'`pop'`age' "Fiscal income (no KG)"
						if "`inc'" == "princ" cap label variable `stat'`inc'`i'`pop'`age' "Pre-tax"
						if "`inc'" == "peinc" cap label variable `stat'`inc'`i'`pop'`age' "Post-pension"
						if "`inc'" == "poinc" cap label variable `stat'`inc'`i'`pop'`age' "Post-tax"
						if "`inc'" == "hweal" cap label variable `stat'`inc'`i'`pop'`age' "Wealth"
					}	
				}
			}	
		}	
	}	

* Compute real values
	foreach var of varlist avg* thres* {
		cap replace `var' = `var' * nideflator
	}

cap format avg*  %12.0fc
cap format thres*  %12.0fc	
sort year
foreach var of varlist _all {
		replace `var' = 0.5 * (`var'[_n-1] + `var'[_n+1]) if (year == 1963 | year == 1965) & `var' == . 
	}	

keep if year>=1913	
saveold $dirgraph/datagraph.dta, replace

********************************************************************************
* Export Excel series to DINA(distrib) 
********************************************************************************

* Export compo of top factor income shares (matching national income)
	use "$dirgraph/datagraph.dta", clear
	keep year shpr*equal99 
	order year *0* *1* *2* *3* *4* *5* *6* *7* *8* *9* *10*
	rename sh*equal99 *
	forval i=0/10 { // define components
		gen prhou`i' = prhoumain`i' + prhourent`i' + prmor`i'
		drop prhoumain`i'  prhourent`i'  prmor`i'
		gen print`i' = prfix`i' + prnmo`i' + prnpinc`i' + prgovin`i'
		drop prfix`i'  prnmo`i'  prnpinc`i' prgovin`i'
	}
	keep year  princ* prequ* print* prhou* prbus* prpen* premp* prmil*
	order year  princ0 prequ0 print0 prhou0 prbus0 prpen0 premp0 prmil0 ///
				princ1 prequ1 print1 prhou1 prbus1 prpen1 premp1 prmil1 /// 
				princ2 prequ2 print2 prhou2 prbus2 prpen2 premp2 prmil2 ///
				princ3 prequ3 print3 prhou3 prbus3 prpen3 premp3 prmil3 /// 
				princ4 prequ4 print4 prhou4 prbus4 prpen4 premp4 prmil4 /// 
				princ5 prequ5 print5 prhou5 prbus5 prpen5 premp5 prmil5 /// 
				princ6 prequ6 print6 prhou6 prbus6 prpen6 premp6 prmil6 ///
				princ7 prequ7 print7 prhou7 prbus7 prpen7 premp7 prmil7 ///
				princ8 prequ8 print8 prhou8 prbus8 prpen8 premp8 prmil8 ///
				princ9 prequ9 print9 prhou9 prbus9 prpen9 premp9 prmil9 ///
			    princ10 prequ10 print10 prhou10 prbus10 prpen10 premp10 prmil10
	 export excel using  "$diroutexcel", first(var) sheetmodify sheet(compoprinc) 
	* mkmat _all, mat(compoprinc)
	* putexcel set "$diroutexcel", modify sheet(compoprinc)
	* putexcel A1 = matrix(compoprinc), colnames


* Export real average factor income, different populations
	use "$dirgraph/datagraph.dta", clear
	keep year avgprinc*99
	rename *99 *
	cap drop avgprinc0equal 
	cap drop *oldwgt
order year   			   avgprinc0indiv  avgprinc0working avgprinc0male avgprinc0female avgprinc0taxu ///
			avgprinc1equal avgprinc1indiv  avgprinc1working avgprinc1male avgprinc1female avgprinc1taxu /// 
			avgprinc2equal avgprinc2indiv  avgprinc2working avgprinc2male avgprinc2female avgprinc2taxu /// 
			avgprinc3equal avgprinc3indiv  avgprinc3working avgprinc3male avgprinc3female avgprinc3taxu /// 
			avgprinc4equal avgprinc4indiv  avgprinc4working avgprinc4male avgprinc4female avgprinc4taxu /// 
			avgprinc5equal avgprinc5indiv  avgprinc5working avgprinc5male avgprinc5female avgprinc5taxu /// 
			avgprinc6equal avgprinc6indiv  avgprinc6working avgprinc6male avgprinc6female avgprinc6taxu /// 
			avgprinc7equal avgprinc7indiv  avgprinc7working avgprinc7male avgprinc7female avgprinc7taxu /// 
			avgprinc8equal avgprinc8indiv  avgprinc8working avgprinc8male avgprinc8female avgprinc8taxu /// 
			avgprinc9equal avgprinc9indiv  avgprinc9working avgprinc9male avgprinc9female avgprinc9taxu /// 
			avgprinc10equal avgprinc10indiv avgprinc10working avgprinc10male avgprinc10female avgprinc10taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(avgprinc)

* Export median factor income, diff pop
 	use "$dirgraph/datagraph.dta", clear
	keep year thresprinc1*99
	rename *99 *
	order year  thresprinc1equal thresprinc1indiv thresprinc1working thresprinc1male thresprinc1female thresprinc1taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(medprinc)
	
* Export compo of top pre-tax income shares (matching national income)
	use "$dirgraph/datagraph.dta", clear
	keep year shpe*equal99 
	order year *0* *1* *2* *3* *4* *5* *6* *7* *8* *9* *10*
	rename sh*equal99 *
	forval i=0/10 { // define components
		gen pehou`i' = pehoumain`i' + pehourent`i' + pemor`i'
		drop pehoumain`i'  pehourent`i'  pemor`i'
		gen peint`i' = pefix`i' + penmo`i' + penpinc`i' + pegovin`i'
		drop pefix`i'  penmo`i'  penpinc`i' pegovin`i'
		gen shemp`i' = peemp`i' / (peemp`i' + pemil`i') // Allocate pension contrib to wages and self-employment income
		replace shemp`i' = 0 if shemp`i' == .
		replace peemp`i' = peemp`i' + pecon`i' * shemp`i'
		replace pemil`i' = pemil`i' + pecon`i' * (1-shemp`i')
		drop shemp`i' pecon`i'
		replace peben`i' = peben`i' + pepen`i' +  peprisupen`i'  
		drop pepen`i' peprisupen`i'
	}
	keep year  peinc* peequ* peint* pehou* pebus* peben* peemp* pemil*
	order year  peinc0 peequ0 peint0 pehou0 pebus0 peben0 peemp0 pemil0 ///
				peinc1 peequ1 peint1 pehou1 pebus1 peben1 peemp1 pemil1 /// 
				peinc2 peequ2 peint2 pehou2 pebus2 peben2 peemp2 pemil2 ///
				peinc3 peequ3 peint3 pehou3 pebus3 peben3 peemp3 pemil3 /// 
				peinc4 peequ4 peint4 pehou4 pebus4 peben4 peemp4 pemil4 /// 
				peinc5 peequ5 peint5 pehou5 pebus5 peben5 peemp5 pemil5 /// 
				peinc6 peequ6 peint6 pehou6 pebus6 peben6 peemp6 pemil6 ///
				peinc7 peequ7 peint7 pehou7 pebus7 peben7 peemp7 pemil7 ///
				peinc8 peequ8 peint8 pehou8 pebus8 peben8 peemp8 pemil8 ///
				peinc9 peequ9 peint9 pehou9 pebus9 peben9 peemp9 pemil9 ///
				peinc10 peequ10 peint10 pehou10 pebus10 peben10 peemp10 pemil10
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(compopeinc) 


* Export real average pre-tax income, different populations
	use "$dirgraph/datagraph.dta", clear
	keep year avgpeinc*99
	rename *99 *
	cap drop avgpeinc0equal 
	cap drop *oldwgt
order year  			   avgpeinc0indiv avgpeinc0working avgpeinc0male avgpeinc0female avgpeinc0taxu ///
			avgpeinc1equal avgpeinc1indiv avgpeinc1working avgpeinc1male avgpeinc1female avgpeinc1taxu /// 
			avgpeinc2equal avgpeinc2indiv avgpeinc2working avgpeinc2male avgpeinc2female avgpeinc2taxu /// 
			avgpeinc3equal avgpeinc3indiv avgpeinc3working avgpeinc3male avgpeinc3female avgpeinc3taxu /// 
			avgpeinc4equal avgpeinc4indiv avgpeinc4working avgpeinc4male avgpeinc4female avgpeinc4taxu /// 
			avgpeinc5equal avgpeinc5indiv avgpeinc5working avgpeinc5male avgpeinc5female avgpeinc5taxu /// 
			avgpeinc6equal avgpeinc6indiv avgpeinc6working avgpeinc6male avgpeinc6female avgpeinc6taxu /// 
			avgpeinc7equal avgpeinc7indiv avgpeinc7working avgpeinc7male avgpeinc7female avgpeinc7taxu /// 
			avgpeinc8equal avgpeinc8indiv avgpeinc8working avgpeinc8male avgpeinc8female avgpeinc8taxu /// 
			avgpeinc9equal avgpeinc9indiv avgpeinc9working avgpeinc9male avgpeinc9female avgpeinc9taxu /// 
			avgpeinc10equal avgpeinc10indiv avgpeinc10working avgpeinc10male avgpeinc10female avgpeinc10taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(avgpeinc)	

* Export median pre-tax income, diff pop
 	use "$dirgraph/datagraph.dta", clear
	keep year threspeinc1*99
	rename *99 *
	order year threspeinc1equal threspeinc1indiv threspeinc1working threspeinc1male threspeinc1female threspeinc1taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(medpeinc)


* Export compo post tax income = income net of taxes + health transfers (medicare + medicaid) + other transfers
	use "$dirgraph/datagraph.dta", clear
	keep year sh*equal99 
	order year *0* *1* *2* *3* *4* *5* *6* *7* *8* *9* *10*
	rename sh*equal99 *
	forval i=0/10 {
		gen transf`i' = cashben`i' + divet`i' + dihlt`i' + dikdn`i' + colexp`i' // all transfers including health
		gen health`i' = dihlt`i' // isolate health transfers 
		gen netinc`i' = poinc`i' - transf`i'
	}
	keep year poinc* netinc* transf* health*
	order year  poinc0 netinc0 transf0 health0  ///
				poinc1 netinc1 transf1 health1  /// 
				poinc2 netinc2 transf2 health2  ///
				poinc3 netinc3 transf3 health3  /// 
				poinc4 netinc4 transf4 health4  /// 
				poinc5 netinc5 transf5 health5  /// 
				poinc6 netinc6 transf6 health6  ///
				poinc7 netinc7 transf7 health7  ///
				poinc8 netinc8 transf8 health8  ///
				poinc9 netinc9 transf9 health9  ///
				poinc10 netinc10 transf10 health10 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(compopoinc) 

* Export real average post-tax income, different populations
	use "$dirgraph/datagraph.dta", clear
	keep year avgpoinc*99
	rename *99 *
	cap drop avgpoinc0equal 
	cap drop *oldwgt
order year   			   avgpoinc0indiv avgpoinc0working avgpoinc0male avgpoinc0female avgpoinc0taxu ///
			avgpoinc1equal avgpoinc1indiv avgpoinc1working avgpoinc1male avgpoinc1female avgpoinc1taxu /// 
			avgpoinc2equal avgpoinc2indiv avgpoinc2working avgpoinc2male avgpoinc2female avgpoinc2taxu /// 
			avgpoinc3equal avgpoinc3indiv avgpoinc3working avgpoinc3male avgpoinc3female avgpoinc3taxu /// 
			avgpoinc4equal avgpoinc4indiv avgpoinc4working avgpoinc4male avgpoinc4female avgpoinc4taxu /// 
			avgpoinc5equal avgpoinc5indiv avgpoinc5working avgpoinc5male avgpoinc5female avgpoinc5taxu /// 
			avgpoinc6equal avgpoinc6indiv avgpoinc6working avgpoinc6male avgpoinc6female avgpoinc6taxu /// 
			avgpoinc7equal avgpoinc7indiv avgpoinc7working avgpoinc7male avgpoinc7female avgpoinc7taxu /// 
			avgpoinc8equal avgpoinc8indiv avgpoinc8working avgpoinc8male avgpoinc8female avgpoinc8taxu /// 
			avgpoinc9equal avgpoinc9indiv avgpoinc9working avgpoinc9male avgpoinc9female avgpoinc9taxu /// 
			avgpoinc10equal avgpoinc10indiv avgpoinc10working avgpoinc10male avgpoinc10female avgpoinc10taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(avgpoinc)	


* Export median post-tax income, diff pop
 	use "$dirgraph/datagraph.dta", clear
	keep year threspoinc1*99
	rename *99 *
	order year  threspoinc1equal threspoinc1indiv threspoinc1working threspoinc1male threspoinc1female threspoinc1taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(medpoinc)



* Export compo of top wealth shares
	use "$dirgraph/datagraph.dta", clear
	keep year shhweal*indiv99 shhwequ*indiv99 shbond*indiv99 shcurrency*indiv99 shnonmort*indiv99 shrental*indiv99 shownerhome*indiv99 shownermort*indiv99 shhwbus*indiv99 shhwpen*indiv99  
	order year *0* *1* *2* *3* *4* *5* *6* *7* *8* *9* *10*
	rename sh*indiv99 *
	forval i=0/10 { // define components
		gen fix`i' = bond`i' + currency`i' + nonmort`i' 
		gen housing`i' = rental`i' + ownerhome`i' + ownermort`i'  
	}
	keep year  hweal*  hwequ*  fix*  housing*  hwbus*  hwpen*
	order year  hweal0  hwequ0  fix0  housing0  hwbus0  hwpen0  ///
				hweal1  hwequ1  fix1  housing1  hwbus1  hwpen1  /// 
				hweal2  hwequ2  fix2  housing2  hwbus2  hwpen2  ///
				hweal3  hwequ3  fix3  housing3  hwbus3  hwpen3  /// 
				hweal4  hwequ4  fix4  housing4  hwbus4  hwpen4  /// 
				hweal5  hwequ5  fix5  housing5  hwbus5  hwpen5  /// 
				hweal6  hwequ6  fix6  housing6  hwbus6  hwpen6  ///
				hweal7  hwequ7  fix7  housing7  hwbus7  hwpen7  ///
				hweal8  hwequ8  fix8  housing8  hwbus8  hwpen8  ///
				hweal9  hwequ9  fix9  housing9  hwbus9  hwpen9  ///
				hweal10 hwequ10 fix10 housing10 hwbus10 hwpen10 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(compohweal) 


* Export real average wealth, different populations
	use "$dirgraph/datagraph.dta", clear
	keep year avghweal*99
	rename *99 *
	cap drop avghweal0equal
	cap drop *oldwgt
order year   			 	avghweal0indiv  avghweal0working  avghweal0male  avghweal0female  avghweal0taxu ///
			avghweal1equal  avghweal1indiv  avghweal1working  avghweal1male  avghweal1female  avghweal1taxu /// 
			avghweal2equal  avghweal2indiv  avghweal2working  avghweal2male  avghweal2female  avghweal2taxu /// 
			avghweal3equal  avghweal3indiv  avghweal3working  avghweal3male  avghweal3female  avghweal3taxu /// 
			avghweal4equal  avghweal4indiv  avghweal4working  avghweal4male  avghweal4female  avghweal4taxu /// 
			avghweal5equal  avghweal5indiv  avghweal5working  avghweal5male  avghweal5female  avghweal5taxu /// 
			avghweal6equal  avghweal6indiv  avghweal6working  avghweal6male  avghweal6female  avghweal6taxu /// 
			avghweal7equal  avghweal7indiv  avghweal7working  avghweal7male  avghweal7female  avghweal7taxu /// 
			avghweal8equal  avghweal8indiv  avghweal8working  avghweal8male  avghweal8female  avghweal8taxu /// 
			avghweal9equal  avghweal9indiv  avghweal9working  avghweal9male  avghweal9female  avghweal9taxu /// 
			avghweal10equal avghweal1indiv  avghweal10working avghweal10male avghweal10female avghweal10taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(avghweal)


* Export compo of top fiscal income shares 
	use "$dirgraph/datagraph.dta", clear
	keep year shfi*taxu99 shfn*taxu99  
	order year *0* *1* *2* *3* *4* *5* *6* *7* *8* *9* *10*
	rename sh*taxu99 *
	keep year fiinc* fn*
	order year  fiinc0  fninc0  fnwag0  fnbus0  fndiv0  fnint0  fnren0  ///
				fiinc1  fninc1  fnwag1  fnbus1  fndiv1  fnint1  fnren1  /// 
				fiinc2  fninc2  fnwag2  fnbus2  fndiv2  fnint2  fnren2  ///
				fiinc3  fninc3  fnwag3  fnbus3  fndiv3  fnint3  fnren3  /// 
				fiinc4  fninc4  fnwag4  fnbus4  fndiv4  fnint4  fnren4  /// 
				fiinc5  fninc5  fnwag5  fnbus5  fndiv5  fnint5  fnren5  /// 
				fiinc6  fninc6  fnwag6  fnbus6  fndiv6  fnint6  fnren6  ///
				fiinc7  fninc7  fnwag7  fnbus7  fndiv7  fnint7  fnren7  ///
				fiinc8  fninc8  fnwag8  fnbus8  fndiv8  fnint8  fnren8  ///
				fiinc9  fninc9  fnwag9  fnbus9  fndiv9  fnint9  fnren9  ///
				fiinc10	fninc10 fnwag10 fnbus10 fndiv10 fnint10 fnren10 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(compofiinc) 


* Export real average fiscal income, different populations
	use "$dirgraph/datagraph.dta", clear
	keep year avgfiinc*99
	rename *99 *
	cap drop avgfiinc0equal 
	cap drop *oldwgt
order year   			   avgfiinc0indiv avgfiinc0working avgfiinc0male avgfiinc0female avgfiinc0taxu ///
			avgfiinc1equal avgfiinc1indiv avgfiinc1working avgfiinc1male avgfiinc1female avgfiinc1taxu /// 
			avgfiinc2equal avgfiinc2indiv avgfiinc2working avgfiinc2male avgfiinc2female avgfiinc2taxu /// 
			avgfiinc3equal avgfiinc3indiv avgfiinc3working avgfiinc3male avgfiinc3female avgfiinc3taxu /// 
			avgfiinc4equal avgfiinc4indiv avgfiinc4working avgfiinc4male avgfiinc4female avgfiinc4taxu /// 
			avgfiinc5equal avgfiinc5indiv avgfiinc5working avgfiinc5male avgfiinc5female avgfiinc5taxu /// 
			avgfiinc6equal avgfiinc6indiv avgfiinc6working avgfiinc6male avgfiinc6female avgfiinc6taxu /// 
			avgfiinc7equal avgfiinc7indiv avgfiinc7working avgfiinc7male avgfiinc7female avgfiinc7taxu /// 
			avgfiinc8equal avgfiinc8indiv avgfiinc8working avgfiinc8male avgfiinc8female avgfiinc8taxu /// 
			avgfiinc9equal avgfiinc9indiv avgfiinc9working avgfiinc9male avgfiinc9female avgfiinc9taxu /// 
			avgfiinc10equal avgfiinc10indiv avgfiinc10working avgfiinc10male avgfiinc10female avgfiinc10taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(avgfiinc)


* Export median fiscal income, diff pop
 	use "$dirgraph/datagraph.dta", clear
	keep year thresfiinc1*99 
	rename *99 *
	order year thresfiinc1equal thresfiinc1indiv thresfiinc1working thresfiinc1male thresfiinc1female thresfiinc1taxu 
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(medfiinc)


* Put detailed composition of pre-tax income in Excel
	import excel "$diroutsheet/detailcompopeinc.xlsx", first clear
	rename c1 year	
	order year ///
	peinc0	div_c0	ret_c0	equi_s0	inte0	hous0	mixk0	pen_k0	pen_l0	comp0	mixl0	mixk_s0	mixk_p0	mixl_s0	mixl_p0	///
	peinc1	div_c1	ret_c1	equi_s1	inte1	hous1	mixk1	pen_k1	pen_l1	comp1	mixl1	mixk_s1	mixk_p1	mixl_s1	mixl_p1	///
	peinc2	div_c2	ret_c2	equi_s2	inte2	hous2	mixk2	pen_k2	pen_l2	comp2	mixl2	mixk_s2	mixk_p2	mixl_s2	mixl_p2	///
	peinc3	div_c3	ret_c3	equi_s3	inte3	hous3	mixk3	pen_k3	pen_l3	comp3	mixl3	mixk_s3	mixk_p3	mixl_s3	mixl_p3	///
	peinc4	div_c4	ret_c4	equi_s4	inte4	hous4	mixk4	pen_k4	pen_l4	comp4	mixl4	mixk_s4	mixk_p4	mixl_s4	mixl_p4	///
	peinc5	div_c5	ret_c5	equi_s5	inte5	hous5	mixk5	pen_k5	pen_l5	comp5	mixl5	mixk_s5	mixk_p5	mixl_s5	mixl_p5	///
	peinc6	div_c6	ret_c6	equi_s6	inte6	hous6	mixk6	pen_k6	pen_l6	comp6	mixl6	mixk_s6	mixk_p6	mixl_s6	mixl_p6	///
	peinc7	div_c7	ret_c7	equi_s7	inte7	hous7	mixk7	pen_k7	pen_l7	comp7	mixl7	mixk_s7	mixk_p7	mixl_s7	mixl_p7
	export excel using  "$diroutexcel", first(var) sheetreplace sheet(compopeincdet)
