* Creates pre-62 series starting from post-1962 composition tables produced by outsheet_dina
* and using Piketty-Saez series before 1962

if $source == 0 {
	global diroutsheet "$root/output/ToExcel"
}	
if $source == 1 {
	global diroutsheet "$root/output/ToExcelInternal"
}


********************************************************************************
* IMPORT PIKETTY-SAEZ SERIES
********************************************************************************

local lastyear = 2020
cap mkdir "$diroutput/pre62"	

cd $direxcel
*copy "https://eml.berkeley.edu/~saez/TabFig2018.xls" "TabFig2018.xls", replace
cd $root

* Top shares excluding KG in ranks and shares
	import excel "$direxcel/TabFig2018.xls", clear sheet(Table A1)
	keep if _n>5
	qui rename A year
	destring year, force replace
	rename B fninc2
	rename C fninc3
	rename D fninc4
	rename E fninc5
	rename F fninc6
	rename G fninc7 
	keep year fn*
	foreach var of varlist fn* {
		destring `var', force replace
		replace `var' = `var' / 100
	}
	keep if year<=`lastyear'
	saveold "$diroutput/pre62/pre62comp.dta", replace	

* Top shares including KG in ranks and shares
	import excel "$direxcel/TabFig2018.xls", clear sheet(Table A3)
	keep if _n>5
	qui rename A year
	destring year, force replace
	rename B fiinc2
	rename C fiinc3
	rename D fiinc4
	rename E fiinc5
	rename F fiinc6
	rename G fiinc7 
	keep year fi*
	foreach var of varlist fi* {
		destring `var', force replace
		replace `var' = `var' / 100
	}
	keep if year<=`lastyear'
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Compo excluding KG
	import excel "$direxcel/TabFig2018.xls", clear sheet(Table A7) 
	keep if _n>6
	qui rename A year
	destring year, force replace
	rename B fnwag2
	rename C fnbus2
	rename D fndiv2
	rename E fnint2
	rename F fnren2
	
	rename I fnwag3
	rename J fnbus3
	rename K fndiv3
	rename L fnint3
	rename M fnren3

	rename P fnwag4
	rename Q fnbus4
	rename R fndiv4
	rename S fnint4
	rename T fnren4

	rename W fnwag5
	rename X fnbus5
	rename Y fndiv5
	rename Z fnint5
	rename AA fnren5
	keep year fn*
	foreach var of varlist fn* {
		destring `var', force replace
		replace `var' = `var' / 100
	}
	keep if year<=`lastyear'
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	sort year
	saveold "$diroutput/pre62/pre62comp.dta", replace

	import excel "$direxcel/TabFig2018.xls", clear sheet(Table A7 (cont.)) 
	keep if _n>6
	qui rename A year
	destring year, force replace
	rename B fnwag6
	rename C fnbus6
	rename D fndiv6
	rename E fnint6
	rename F fnren6
	
	rename I fnwag7
	rename J fnbus7
	rename K fndiv7
	rename L fnint7
	rename M fnren7	
	keep year fn*
	foreach var of varlist fn* {
		destring `var', force replace
		replace `var' = `var' /100
	}
	keep if year<=`lastyear'
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	sort year
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Capital gains as % of total income (B-G = fractiles defined incl. KG; Q-V = fractiles defined excluding KG)
	import excel "$direxcel/TabFig2018.xls", clear sheet(Table A8) 
	keep if _n>6
	qui rename A year
	destring year, force replace
	rename B fnkgi2
	rename C fnkgi3
	rename D fnkgi4
	rename E fnkgi5
	rename F fnkgi6
	rename G fnkgi7
	rename Q fikgi2
	rename R fikgi3
	rename S fikgi4
	rename T fikgi5
	rename U fikgi6		
	rename V fikgi7
	keep year fn* fi*
	foreach var of varlist fn* fi* {
		destring `var', force replace
		replace `var' = `var' /100
	}
	keep if year<=`lastyear'
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	sort year
	saveold "$diroutput/pre62/pre62comp.dta", replace

* 1913-1915 components for top 1% and above = assume same as in 1916
	forval i = 4/7 {
		foreach compo in wag bus div int ren kgi {
			forval ii = 1/3 {
				local year = 1916
				replace fn`compo'`i' = fn`compo'`i'[_n+1] if year == `year' - `ii'
			}	
		}
	}

* 1913-1917 top 10% and top 5% shares: assume P90-P95 and P95-P99 have constant shares
gen fn9095=fninc2-fninc3
gen fn9599=fninc3-fninc4
gen fi9095=fiinc2-fiinc3
gen fi9599=fiinc3-fiinc4
		forval ii = 1/4 {
			local year = 1917
			foreach var in fn9095 fn9599 fi9095 fi9599 {
				replace `var' = `var'[_n+1] if year == `year' - `ii'
			}	
		}	
replace fninc3 = fninc4 + fn9599 if year<1917
replace fiinc3 = fiinc4 + fi9599 if year<1917
replace fninc2 = fninc3 + fn9095 if year<1917
replace fiinc2 = fiinc3 + fi9095 if year<1917
drop fn9095 fn9599 fi9095 fi9599

* 1913-1916 components for top 5%: assume same compo as 1917	
	foreach compo in wag bus div int ren kgi {
		forval ii = 1/4 {
			local year = 1917
			replace fn`compo'3 = fn`compo'3[_n+1] if year == `year' - `ii'
		}	
	}

* 1913-1917 components for top 10%: assume same compo as 1918	
	foreach compo in wag bus div int ren kgi {
		forval ii = 1/5 {
			local year = 1918
			replace fn`compo'2 = fn`compo'2[_n+1] if year == `year' - `ii'
		}	
	}	
	saveold "$diroutput/pre62/pre62comp.dta", replace


* Compute component by component shares (= frac) and mean frac in 1962-1963
	qui import excel using "$parameters", firstrow clear 
	keep yr piksaez* 
	rename yr year
	keep if year>=1913 & year < `lastyear'
	foreach var of varlist _all {
		destring `var', force replace
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	qui drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace
	forval i = 2/7 {
		foreach compo in wag bus div int ren {
			qui gen fracfn`compo'`i' = fn`compo'`i' * fninc`i' * piksaezden / piksaez`compo'
		}
		qui gen fracfnpen`i' 	= fnwag`i' * fninc`i' * piksaezden / (0.5 * piksaezwag) // assume bottom 50% wags don't get any pension
		qui gen fracdivmix`i' = (fndiv`i' * (1 - fnkgi`i') + fnkgi`i') * fiinc`i' * piksaezdenkg / (piksaezdiv + piksaezdenkg - piksaezden) // div + KG mixed method
		foreach compo in wag bus div int ren wag pen {
			su fracfn`compo'`i' if year == 1962 | year == 1963
			global meanfrac`compo'_`i' = r(mean)
		}
		su fracdivmix`i' if year == 1962 | year == 1963
			global meanfracdivmix_`i' = r(mean)
		*	di "${meanfracdivmix_`i'}"
		*	di "`r(mean)'"
	}		
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Pre-1917 adjustments (same as in SZ 2016 QJE)
	foreach compo in fndiv divmix {
		forval ii = 1/3 {
			local year = 1916
			replace frac`compo'6 = frac`compo'6[_n+1] if year == `year' - `ii'
		}
		replace frac`compo'7 = (frac`compo'7[_n+1] + frac`compo'7[_n-1]) / 2 if year == 1915	
	}
	saveold "$diroutput/pre62/pre62comp.dta", replace

********************************************************************************
* COMPUTE TOP WEALTH SHARES PRE-62
********************************************************************************	

* Same method as in Saez-Zucman: component by component with adjustment in 1962, mixed method for equities

foreach pop in taxu indiv {

* Load totals
	qui import excel using "$parameters", firstrow clear 
	keep yr hwequ0 bond0 currency0 nonmort0 rental0 ownerhome0 ownermort0 hwbus0 hwpen0
	rename yr year
	foreach var of varlist *0 {
		qui rename `var' `var'`pop'
	}
	keep if year>=1913 & year < `lastyear'
	foreach var of varlist _all {
		destring `var', force replace
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	qui drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Import post-62 data
	import excel using "$diroutsheet/compohweal`pop'99.xlsx", first clear
	rename c1 year
	foreach var of varlist hweal* hwequ* bond* currency* nonmort* rental* ownerhome* ownermort* hwbus* hwpen* {
		qui rename `var' `var'`pop'
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	sort year
	foreach var of varlist _all {
		replace `var' = 0.5 * (`var'[_n-1] + `var'[_n+1]) if (year == 1963 | year == 1965) & `var' == .
	}
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Compute component by component shares (= frac)
	forval i = 2/7 {
		foreach compo in hwequ bond currency nonmort rental ownerhome ownermort hwbus hwpen {
			qui gen frac`compo'`i'`pop' = `compo'`i'`pop' / `compo'0`pop'		
		}

* Pre-62 imputations for currency, debt, etc.: fixed shares
		foreach compo in currency nonmort ownerhome ownermort {
			su frac`compo'`i'`pop' if year == 1962 | year == 1963
			local frac`compo'`i'`pop'pre62 = r(mean)
			qui replace frac`compo'`i'`pop' = `frac`compo'`i'`pop'pre62' if year < 1962
		}		
* Pre-62 imputations for equities, bonds, etc.: using fiscal income shares and correcting for reranking in 62
		foreach compo in hwequ bond rental hwbus hwpen {
			su frac`compo'`i'`pop' if year == 1962 | year == 1963
			global meanfrac`compo'_`i'`pop' = r(mean)
		}
		qui replace frachwequ`i'`pop' 	= min(0.95, 1 - (1 - fracdivmix`i') * (1 - ${meanfrachwequ_`i'`pop'}) / (1 - ${meanfracdivmix_`i'})) if year < 1962
		qui replace fracbond`i'`pop' 	= min(0.95, 1 - (1 - fracfnint`i') * (1 - ${meanfracbond_`i'`pop'}) / (1 - ${meanfracint_`i'})) if year < 1962
		qui replace fracrental`i'`pop'	= min(0.95, 1 - (1 - fracfnren`i') * (1 - ${meanfracrental_`i'`pop'}) / (1 - ${meanfracren_`i'})) if year < 1962
		qui replace frachwbus`i'`pop' 	= min(0.95, 1 - (1 - fracfnbus`i') * (1 - ${meanfrachwbus_`i'`pop'}) / (1 - ${meanfracbus_`i'})) if year < 1962
		qui replace frachwpen`i'`pop' 	= min(0.95, 1 - (1 - fracfnpen`i') * (1 - ${meanfrachwpen_`i'`pop'}) / (1 - ${meanfracpen_`i'})) if year < 1962

* Pre-62 wealth and components as % of total household wealth
		qui replace hweal`i'`pop' = 0 if year < 1962
		foreach compo in hwequ bond currency nonmort rental ownerhome ownermort hwbus hwpen {
			qui replace `compo'`i'`pop' = frac`compo'`i'`pop' * `compo'0`pop' if year < 1962
			qui replace hweal`i'`pop' = hweal`i'`pop' + `compo'`i'`pop' if year < 1962
		}
	}
	qui replace hweal0`pop' = hwequ0`pop'+ bond0`pop'+ currency0`pop'+ nonmort0`pop'+ rental0`pop'+ ownerhome0`pop'+ ownermort0`pop'+ hwbus0`pop'+ hwpen0`pop' if year < 1962

	saveold "$diroutput/pre62/pre62comp.dta", replace		
}

********************************************************************************
* COMPUTE TOP FACTOR, PRE-TAX, AND POST-TAX INCOME SHARES PRE-62
********************************************************************************	

* Same method as for wealth: component by component with adjustment in 1962
* Use same components as in compo`var' created by outsheet_dina.do 

********************************************************************************
* Factor income (matching national income)
********************************************************************************	


local components  "premp prmil prhoumain prhourent prequ prfix prbus prpen prmor prnmo prnpinc prgovin"

foreach pop in taxu indiv equal {

* Load totals
	qui import excel using "$parameters", firstrow clear 
	keep yr flemp0 flmil0 fkhoumain0 fkhourent0 fkequ0 fkfix0 fkbus0 fkpen0 fkmor0 fknmo0 ttgovint ttnpishinc ttninc
	rename yr year
	rename fl* pr*
	rename fk* pr*
	gen prnpinc0 = ttnpishinc / ttninc
	gen prgovin0 = - ttgovint / ttninc
	replace prfix0 = prfix0 - prnpinc0 - prgovin0 // In parameters fix0 includes nonprofits and govin, not here
	foreach var of varlist *0 {
		qui rename `var' `var'`pop'
	}
	keep if year>=1913 & year < `lastyear'
	foreach var of varlist _all {
		destring `var', force replace
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	qui drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace


* Import post-62 data: income components
	import excel using "$diroutsheet/compoprinc`pop'99.xlsx", first clear
	rename c1 year
	foreach var in princ `components' {	
		forval i = 0/7 {
			qui rename `var'`i' `var'`i'`pop'
		}
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	sort year
	foreach var of varlist _all {
		replace `var' = 0.5 * (`var'[_n-1] + `var'[_n+1]) if (year == 1963 | year == 1965) & `var' == .
	}	
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Compute component by component shares (= frac)
	forval i = 2/7 {
		foreach compo of local components  {
			qui gen frac`compo'`i'`pop' = `compo'`i'`pop' / `compo'0`pop'
			su frac`compo'`i'`pop' if year == 1962 | year == 1963
			global meanfrac`compo'_`i'`pop' = r(mean)		
		}

* Pre-62 imputations for main housing, debt, etc.: fixed shares
		foreach compo in prhoumain prmor prnmo prgovin prnpinc {
			su frac`compo'`i'`pop' if year == 1962 | year == 1963
			local frac`compo'`i'`pop'pre62 = r(mean)
			qui replace frac`compo'`i'`pop' = `frac`compo'`i'`pop'pre62' if year < 1962
		}

* Pre-62 imputations for other components: using fiscal income shares and correcting for reranking in 62
		qui replace fracpremp`i'`pop' 	= min(0.95, 1 - (1 - fracfnwag`i') * (1 - ${meanfracpremp_`i'`pop'}) / (1 - ${meanfracwag_`i'})) if year < 1962
		qui replace fracprmil`i'`pop' 	= min(0.95, 1 - (1 - fracfnbus`i') * (1 - ${meanfracprmil_`i'`pop'}) / (1 - ${meanfracbus_`i'})) if year < 1962
	  	qui replace fracprhourent`i'`pop' = min(0.95, 1 - (1 - fracfnren`i') * (1 - ${meanfracprhourent_`i'`pop'}) / (1 - ${meanfracren_`i'})) if year < 1962
	  	qui replace fracprequ`i'`pop' 	= min(0.95, 1 - (1 - fracdivmix`i') * (1 - ${meanfracprequ_`i'`pop'}) / (1 - ${meanfracdivmix_`i'})) if year < 1962
		qui replace fracprfix`i'`pop' 	= min(0.95, 1 - (1 - fracfnint`i') * (1 - ${meanfracprfix_`i'`pop'}) / (1 - ${meanfracint_`i'})) if year < 1962
		qui replace fracprbus`i'`pop' 	= min(0.95, 1 - (1 - fracfnbus`i') * (1 - ${meanfracprbus_`i'`pop'}) / (1 - ${meanfracbus_`i'})) if year < 1962
		qui replace fracprpen`i'`pop' 	= min(0.95, 1 - (1 - fracfnpen`i') * (1 - ${meanfracprpen_`i'`pop'}) / (1 - ${meanfracpen_`i'})) if year < 1962
	
* Pre-62 income and components as % of total income
		qui replace princ`i'`pop' = 0 if year < 1962
		foreach compo in `components' {
			qui replace `compo'`i'`pop' = frac`compo'`i'`pop' * `compo'0`pop' if year < 1962
			* if `i' >= 4 { // deal with re-ranking at very top due to negative corporate profits // Removed August 2020 as in revised DINA(Aggreg), corp. profits are positive in early 1930s
			* 	if "`compo'" == "prequ" qui replace prequ`i'`pop'	= 0.05 * hwequ`i'indiv * 4.76  if year == 1931
			* 	if "`compo'" == "prequ" qui replace prequ`i'`pop'	= 0.03 * hwequ`i'indiv * 5.03  if year == 1932
			* 	if "`compo'" == "prequ" qui replace prequ`i'`pop'	= 0.03 * hwequ`i'indiv * 5.48  if year == 1933   
			* }
			* if `i' == 2 { // deal with re-ranking at very top due to negative corporate profits
			* 	if "`compo'" == "prequ" qui replace prequ`i'`pop'	= 0.01 * hwequ`i'indiv * 5.03  if year == 1932
			* 	if "`compo'" == "prequ" qui replace prequ`i'`pop'	= 0.01 * hwequ`i'indiv * 5.48  if year == 1933   
			* }
			qui replace princ`i'`pop' = princ`i'`pop' + `compo'`i'`pop' if year < 1962
		}
	}

	qui replace princ0`pop' = 0 if year < 1962
	foreach compo in `components' {
		qui replace princ0`pop' = princ0`pop' + `compo'0`pop' if year < 1962 
	}

	sort year
	saveold "$diroutput/pre62/pre62comp.dta", replace		
}

********************************************************************************
* Pre-tax income (matching national income)
********************************************************************************

local components "peemp pemil peben pecon pehoumain pehourent peequ pefix pebus pemor penmo penpinc pegovin pepen peprisupen"

foreach pop in taxu indiv equal {

* Load totals
	qui import excel using "$parameters", firstrow clear 
	keep yr flemp0 flmil0 fkhoumain0 fkhourent0 fkequ0 fkfix0 fkbus0 fkmor0 fknmo0 ttplcon ttpenben ttuidiben ttinvincpen fkpen0  ttgovint ttnpishinc ttninc ttprisupss  ttprisupenprivate
	rename fl* pe*
	rename fk* pe*
	gen pecon0 = - ttplcon / ttninc
	gen peben0 =  (ttpenben + ttuidiben) / ttninc
	gen pegovin0 = - ttgovint / ttninc
	gen penpinc0 = ttnpishinc / ttninc
	replace pefix0 = pefix0 - penpinc0 - pegovin0 // In parameters fix0 includes nonprofits and govin, not here	
	gen peprisupen0 = (ttprisupss + ttprisupenprivate) / ttninc
	rename yr year
	foreach var of varlist *0 {
		qui rename `var' `var'`pop'
	}
	keep if year>=1913 & year < `lastyear'
	foreach var of varlist _all {
		destring `var', force replace
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	qui drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Import post-62 data: income components
	import excel using "$diroutsheet/compopeinc`pop'99.xlsx", first clear
	rename c1 year
	foreach var in peinc `components' {
		forval i = 0/7 {
			qui rename `var'`i' `var'`i'`pop'
		}
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	sort year
	foreach var of varlist _all {
		replace `var' = 0.5 * (`var'[_n-1] + `var'[_n+1]) if (year == 1963 | year == 1965) & `var' == . 
	}	
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Compute component by component shares (= frac)
	forval i = 2/7 {
		foreach compo of local components {
			qui gen frac`compo'`i'`pop' = `compo'`i'`pop' / `compo'0`pop'
			su frac`compo'`i'`pop' if year == 1962 | year == 1963
			global meanfrac`compo'_`i'`pop' = r(mean)		
		}

* Pre-62 imputations for main housing, debt, and social insurance contributions & benefits etc.: fixed shares
		foreach compo in pehoumain pemor penmo peben pecon penpinc pegovin peprisupen {
			su frac`compo'`i'`pop' if year == 1962 | year == 1963
			local frac`compo'`i'`pop'pre62 = r(mean)
			qui replace frac`compo'`i'`pop' = `frac`compo'`i'`pop'pre62' if year < 1962
		}

* Pre-62 imputations for other components: using fiscal income shares and correcting for reranking in 62		
		qui replace fracpeemp`i'`pop' 	= min(0.95, 1 - (1 - fracfnwag`i') * (1 - ${meanfracpeemp_`i'`pop'}) / (1 - ${meanfracwag_`i'})) if year < 1962
		qui replace fracpemil`i'`pop' 	= min(0.95, 1 - (1 - fracfnbus`i') * (1 - ${meanfracpemil_`i'`pop'}) / (1 - ${meanfracbus_`i'})) if year < 1962
	  	qui replace fracpehourent`i'`pop' = min(0.95, 1 - (1 - fracfnren`i') * (1 - ${meanfracpehourent_`i'`pop'}) / (1 - ${meanfracren_`i'})) if year < 1962
		qui replace fracpeequ`i'`pop' 	= min(0.95, 1 - (1 - fracdivmix`i') * (1 - ${meanfracpeequ_`i'`pop'}) / (1 - ${meanfracdivmix_`i'})) if year < 1962
		qui replace fracpefix`i'`pop' 	= min(0.95, 1 - (1 - fracfnint`i') * (1 - ${meanfracpefix_`i'`pop'}) / (1 - ${meanfracint_`i'})) if year < 1962
		qui replace fracpebus`i'`pop' 	= min(0.95, 1 - (1 - fracfnbus`i') * (1 - ${meanfracpebus_`i'`pop'}) / (1 - ${meanfracbus_`i'})) if year < 1962
		qui replace fracpepen`i'`pop' 	= min(0.95, 1 - (1 - fracfnpen`i') * (1 - ${meanfracpepen_`i'`pop'}) / (1 - ${meanfracpen_`i'})) if year < 1962
		
* Pre-62 income and components as % of total income
		qui replace peinc`i'`pop' = 0 if year < 1962
		foreach compo in `components' {
			qui replace `compo'`i'`pop' = frac`compo'`i'`pop' * `compo'0`pop' if year < 1962
			* if `i' >= 4 { // deal with re-ranking at very top due to negative corporate profits
			* 	if "`compo'" == "peequ" qui replace peequ`i'`pop'	= 0.05 * hwequ`i'indiv * 4.76  if year == 1931
			* 	if "`compo'" == "peequ" qui replace peequ`i'`pop'	= 0.03 * hwequ`i'indiv * 5.03  if year == 1932
			* 	if "`compo'" == "peequ" qui replace peequ`i'`pop'	= 0.03 * hwequ`i'indiv * 5.48  if year == 1933   
			* }
			* if `i' == 2 { // deal with re-ranking at very top due to negative corporate profits
			* 	if "`compo'" == "peequ" qui replace peequ`i'`pop'	= 0.01 * hwequ`i'indiv * 5.03  if year == 1932
			* 	if "`compo'" == "peequ" qui replace peequ`i'`pop'	= 0.01 * hwequ`i'indiv * 5.48  if year == 1933   
			* }	
			qui replace peinc`i'`pop' = peinc`i'`pop' + `compo'`i'`pop' if year < 1962
		}
	}

	qui replace peinc0`pop' = 0 if year < 1962
	foreach compo in `components' {
		qui replace peinc0`pop' = peinc0`pop' + `compo'0`pop' if year < 1962 
	}
	sort year
	saveold "$diroutput/pre62/pre62comp.dta", replace		
}

********************************************************************************
* Post-tax income (matching national income)
********************************************************************************

local components "ptinc producttax proprestax ditax estatetax corptax propbustax othercontrib cashben divet dihlt dikdn colexp pogovin ponpinc prisupenprivate invpen prisupgov"


foreach pop in taxu indiv equal {

* Load totals
	qui import excel using "$parameters", firstrow clear 
	keep yr ttninc ttdivw ttscorw ttschcpartw ttdikin ttptinc ttflprl ttfkprk ttproptax_res ttproptax_bus ttfedtax ttstatetax ttestatetax ttfkcot ttothcon ttnonvetben ttvetben ttmedicare ttmedicaid ttothinkind ttcolexp  ttoacont ttsecont_oa ttdicont ttsecont_di ttuicont ttwealth ttrestw ttrentw ttrentmortw ttgovint ttnpishinc ttprisupenprivate ttinvincpen ttprimsupgov
	gen ptinc0 = ttptinc / ttninc
	gen producttax0 = - (ttflprl + ttfkprk) / ttninc
	gen proprestax0 = - ttproptax_res / ttninc
	gen ditax0 = - (ttfedtax + ttstatetax) / ttninc
	gen estatetax0 = - ttestatetax / ttninc
	gen corptax0 = - (ttfkcot) / ttninc
	gen propbustax0 = - (ttproptax_bus) / ttninc
	gen othercontrib0 = - ttothcon / ttninc
	gen cashben0 = ttnonvetben / ttninc
	gen divet0 = ttvetben / ttninc
	gen dihlt0 = (ttmedicare + ttmedicaid) / ttninc	
	gen dikdn0 = ttothinkind / ttninc
	gen colexp0 = ttcolexp / ttninc
	gen h0     = (ttrestw + ttrentw - ttrentmortw) / ttwealth
	gen nh0	   = (ttwealth - (ttrestw + ttrentw - ttrentmortw)) / ttwealth
	gen bus0   = (ttdivw + ttscorw + ttschcpartw) / ttwealth
	gen pogovin0 = - ttgovint / ttninc
	gen ponpinc0 = ttnpishinc / ttninc
	gen prisupenprivate0 = ttprisupenprivate / ttninc
	gen invpen0 =  ttinvincpen / ttninc
	gen prisupgov0 = ttprimsupgov / ttninc

	rename yr year
	foreach var of varlist *0 {
		qui rename `var' `var'`pop'
	}
	keep if year>=1913 & year < `lastyear'
	foreach var of varlist _all {
		destring `var', force replace
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	qui drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Import post-62 data: income components
	import excel using "$diroutsheet/compopoinc`pop'99.xlsx", first clear
	rename c1 year
	foreach var in poinc `components'  {
		forval i = 0/7 {
			qui rename `var'`i' `var'`i'`pop'
		}
	}
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	sort year
	foreach var of varlist _all {
		replace `var' = 0.5 * (`var'[_n-1] + `var'[_n+1]) if (year == 1963 | year == 1965) & `var' == .
	}	
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Compute component by component shares (= frac)
	forval i = 2/7 {
		foreach compo of local components {
			qui gen frac`compo'`i'`pop' = `compo'`i'`pop' / `compo'0`pop'
			su frac`compo'`i'`pop' if year == 1962 | year == 1963
			global meanfrac`compo'_`i'`pop' = r(mean)		
		}
	}
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Load frac estate tax paid
	import excel "$root/rawdata/rawexcel/taxratespre62.xls", clear sheet(results-estatetax)
	keep if _n>2 & _n < 110
	qui rename A year
	destring year, force replace
	rename I fracestatetax0
	rename J fracestatetax2
	rename K fracestatetax3
	rename L fracestatetax4
	rename M fracestatetax5
	rename N fracestatetax6 
	rename O fracestatetax7 
	keep year frac*
	foreach var of varlist frac* {
		destring `var', force replace
		replace `var' = 0 if `var' == .
	}
	drop if year==.
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Load frac income tax paid
	import excel "$root/rawdata/rawexcel/taxratespre62.xls", clear sheet(results-incometax)
	keep if _n>2 & _n < 56
	qui rename A year
	destring year, force replace
	rename S fracfedtax0
	rename T fracfedtax2
	rename U fracfedtax3
	rename V fracfedtax4
	rename W fracfedtax5
	rename X fracfedtax6 
	rename Y fracfedtax7 
	keep year frac*
	foreach var of varlist frac* {
		destring `var', force replace
		replace `var' = 0 if `var' == . & year==1913
	}
	drop if year==.
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Pre-62 imputations for other Social contrib, sales tax (fixed fractions) and health benefits (medicare = medicaid = 0 before 1966)
	forval i = 2/7 {	
		foreach compo in othercontrib producttax pogovin ponpinc prisupenprivate prisupgov divet { // August 2020: add divet here to fix discontinuity in 1962
			su frac`compo'`i'`pop' if year == 1962 | year == 1963
			local frac`compo'`i'`pop'pre62 = r(mean)
			replace frac`compo'`i'`pop' = `frac`compo'`i'`pop'pre62' if year < 1962
		}
		replace fracdihlt`i'`pop' = 0 if year < 1966

* Pre-62 imputations for all other components of diposable income: 
		su peinc`i'`pop' if year == 1962 | year == 1963 
			global meanpeinc_`i'`pop' = r(mean)	
		replace fracptinc`i'`pop'   = 1 - (1 - peinc`i'`pop') * (1 - ${meanfracptinc_`i'`pop'}) / (1 - ${meanpeinc_`i'`pop'}) if year < 1962 // ptinc follows peinc
		
		if "`pop'" != "equal" {
			qui gen h`i'`pop' 	= rental`i'`pop' + ownerhome`i'`pop'
			qui gen nh`i'`pop' 	= hweal`i'`pop' - h`i'`pop'
			qui gen bus`i'`pop' = hwequ`i'`pop' + hwbus`i'`pop' 
		}
		if "`pop'" == "equal" {
			qui gen h`i'`pop' 	= rental`i'indiv + ownerhome`i'indiv
			qui gen nh`i'`pop' 	= hweal`i'indiv - h`i'indiv
			qui gen bus`i'`pop' = hwequ`i'indiv + hwbus`i'indiv
		}

		qui gen frach`i'`pop' = h`i'`pop' / h0`pop'	
			qui su frach`i'`pop' if year == 1962 | year == 1963
			global meanh_`i'`pop' = r(mean)	
		qui gen fracnh`i'`pop' = nh`i'`pop' / nh0`pop'
			qui su fracnh`i'`pop' if year == 1962 | year == 1963
			global meannh_`i'`pop' = r(mean)
		qui gen fracbus`i'`pop' = bus`i'`pop' / bus0`pop'
			qui su fracbus`i'`pop' if year == 1962 | year == 1963
			global meanbus_`i'`pop' = r(mean)			
		if "`pop'" != "taxu" qui gen fraceq`i'`pop' = hwequ`i'indiv / hwequ0indiv
		if "`pop'" == "taxu" qui gen fraceq`i'`pop' = hwequ`i'taxu / hwequ0taxu
			qui su fraceq`i'`pop' if year == 1962 | year == 1963
			global meaneq_`i'`pop' = r(mean)			
		if "`pop'" != "equal" {
			qui replace fracproprestax`i'`pop' = 1 - (1 - frach`i'`pop') * (1 - ${meanfracproprestax_`i'`pop'}) / (1 - ${meanh_`i'`pop'}) if year < 1962 // follows housing wealth 
			qui replace fracpropbustax`i'`pop' = 1 - (1 - fracbus`i'`pop') * (1 - ${meanfracpropbustax_`i'`pop'}) / (1 - ${meanbus_`i'`pop'}) if year < 1962 // follows equity and business assets 
			qui replace fraccorptax`i'`pop' = 1 - (1 - fraceq`i'`pop') * (1 - ${meanfraccorptax_`i'`pop'}) / (1 - ${meaneq_`i'`pop'}) if year < 1962 // follows equity wealth
		}	
		if "`pop'" == "equal" {
			qui replace fracproprestax`i'`pop' = 1 - (1 - frach`i'indiv) * (1 - ${meanfracproprestax_`i'`pop'}) / (1 - ${meanh_`i'indiv}) if year < 1962  
			qui replace fracpropbustax`i'`pop' = 1 - (1 - fracbus`i'indiv) * (1 - ${meanfracpropbustax_`i'`pop'}) / (1 - ${meanbus_`i'indiv}) if year < 1962
			qui replace fraccorptax`i'`pop' = 1 - (1 - fraceq`i'indiv) * (1 - ${meanfraccorptax_`i'`pop'}) / (1 - ${meaneq_`i'indiv}) if year < 1962
		}	
		qui su fracfedtax`i' if year == 1962 | year == 1963
			global meanfracfedtax_`i' = r(mean)	
		qui replace fracditax`i'`pop' = 1 - (1 - fracfedtax`i') * (1 - ${meanfracditax_`i'`pop'}) / (1 - ${meanfracfedtax_`i'}) if year < 1962 
		qui su fracestatetax`i' if year == 1962 | year == 1963
			global meanfracestatetax_`i' = r(mean)	
		qui replace fracestatetax`i'`pop' = min(0.95, 1 - (1 - fracestatetax`i') * (1 - ${meanfracestatetax_`i'`pop'}) / (1 - ${meanfracestatetax_`i'})) if year < 1962 
		qui replace fraccashben`i'`pop' = 0  if year < 1962 // Worker comp, AFDC, other in cash: all for bottom 90%
		* if `i' == 2 qui replace fracdivet`i'`pop' = .1 if year < 1962 // Veteran benefits = capitation = top 10% has 10%, etc. August 2020: removed and dealt above to smooth discontinuity in 1962
		* if `i' == 3 qui replace fracdivet`i'`pop' = .05 if year < 1962
		* if `i' == 4 qui replace fracdivet`i'`pop' = .01 if year < 1962
		* if `i' == 5 qui replace fracdivet`i'`pop' = .005 if year < 1962
		* if `i' == 6 qui replace fracdivet`i'`pop' = .001 if year < 1962
		* if `i' == 7 qui replace fracdivet`i'`pop' = .0001 if year < 1962
		qui replace fracdikdn`i'`pop' = 0 if year < 1962 //  Other in kind benefits: all for bottom 90%
		if `i' == 7 { // Cap taxes of top 0.01% to 130% of taxes paid by top 0.1% in the 1930s
			foreach t in proprestax corptax propbustax ditax estatetax producttax othercontrib {
				qui replace frac`t'7`pop' = (`t'6`pop' / (fracptinc6`pop' * ptinc0`pop') * 1.3) * (fracptinc7`pop' * ptinc0`pop') / `t'0`pop' if year > 1930 & year <= 1940 
			}
		}
		qui replace fracinvpen`i'`pop' 	= min(0.95, 1 - (1 - fracfnpen`i') * (1 - ${meanfracinvpen_`i'`pop'}) / (1 - ${meanfracpen_`i'})) if year < 1962
		gen dikin`i'`pop' = 0 if year < 1962 //  Generate disposable cash + kind income (excl. coll exp)
		foreach compo in ptinc producttax proprestax ditax estatetax corptax propbustax othercontrib cashben divet dihlt dikdn { 
			qui replace dikin`i'`pop' = dikin`i'`pop' + frac`compo'`i'`pop' * `compo'0`pop' * ttninc / ttdikin if year < 1962			
		}
		qui replace fraccolexp`i'`pop' = dikin`i'`pop' if year < 1962 // prop to disposable cash + kind transfer income

	
* Pre-62 income and components as % of total income
		qui replace poinc`i'`pop' = 0 if year < 1962
		foreach compo in `components' {
			qui replace `compo'`i'`pop' = frac`compo'`i'`pop' * `compo'0`pop' if year < 1962
			qui replace poinc`i'`pop' = poinc`i'`pop' + `compo'`i'`pop' if year < 1962
		}
	}
	qui replace poinc0`pop' = 0 if year < 1962
	foreach compo in `components' {
		qui replace poinc0`pop' = poinc0`pop' + `compo'0`pop' if year < 1962 
	}
	saveold "$diroutput/pre62/pre62comp.dta", replace	
}


********************************************************************************
* PREPARE PRE62COMP.DATA
********************************************************************************

use "$diroutput/pre62/pre62comp.dta", clear

* Change Piketty-Saez components to express them as % of total fiscal income
* Note: in PS, no composition tables when units ranked by income incl. KG (i.e., no fiwag`i', etc.)
	foreach i of numlist 2/7 {
		foreach compo in wag bus div int ren kgi  {
			replace fn`compo'`i' = fn`compo'`i' * fninc`i'
		}
		replace fikgi`i' = fikgi`i' * fiinc`i'
	}
	gen fnwag0 = piksaezwag / piksaezden 
	gen fnbus0 = piksaezbus / piksaezden
	gen fndiv0 = piksaezdiv / piksaezden
	gen fnint0 = piksaezint / piksaezden
	gen fnren0 = piksaezren / piksaezden
	gen fnkgi0 = (piksaezdenkg - piksaezden) / piksaezden
	gen fiwag0 = piksaezwag / piksaezdenkg 
	gen fibus0 = piksaezbus / piksaezdenkg
	gen fidiv0 = piksaezdiv / piksaezdenkg
	gen fiint0 = piksaezint / piksaezdenkg
	gen firen0 = piksaezren / piksaezdenkg
	gen fikgi0 = (piksaezdenkg - piksaezden) / piksaezdenkg
	gen fiinc0 = 1
	gen fninc0 = 1
	foreach var of varlist fn* fi* {
		rename `var' `var'taxu
	}
	
* Create component by components for bottom 90% (= *9)
foreach var of varlist *0equal { 
	local j =substr("`var'",1,length("`var'")-6)
	cap gen `j'9equal = `j'0equal - `j'2equal
}	
foreach var of varlist *0indiv { 
	local j =substr("`var'",1,length("`var'")-6)
	cap gen `j'9indiv = `j'0indiv - `j'2indiv
}	
foreach var of varlist *0taxu { 
	local j =substr("`var'",1,length("`var'")-5)
	cap gen `j'9taxu = `j'0taxu - `j'2taxu
}

* Rename shares in sh`var'`pop'`age' format 
	drop piksaez* frac* tt* 
	ds year, not
	foreach var of varlist `r(varlist)' {
		rename `var' sh`var'99
	}
	saveold "$diroutput/pre62/pre62comp.dta", replace


********************************************************************************
* Create averages
********************************************************************************

*use  "$diroutput/pre62/pre62comp.dta", clear

* Bring population totals
qui import excel using "$parameters", firstrow clear 
	keep yr totadults20 tottaxunits piksaezden piksaezdenkg ttfainc ttptinc ttninc ttninc ttwealth
	rename yr year
	rename piksaezden ttfninc
	rename piksaezdenkg ttfiinc
	rename ttwealth tthweal
	gen ttprinc = ttninc
	gen ttpeinc = ttninc
	gen ttpoinc = ttninc
	keep if year>=1913 & year < `lastyear'
	merge 1:1 year using "$diroutput/pre62/pre62comp.dta"
	qui drop _merge
	saveold "$diroutput/pre62/pre62comp.dta", replace

* Create averages in avg`var'`i'`pop'`age' format 

	rename totadults20 totindiv
	gen totequal = totindiv
	rename tottaxunits tottaxu 
	foreach pop in taxu indiv equal {
		foreach var in fiinc fninc princ peinc poinc hweal {
				foreach age in 99 {
					foreach i of numlist 0/7 9 {
						quietly {
						if `i' == 0 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (1 * tot`pop')
						if `i' == 1 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (0.5 * tot`pop')
						if `i' == 2 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (0.1 * tot`pop')
						if `i' == 3 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (0.05 * tot`pop')
						if `i' == 4 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (0.01 * tot`pop')
						if `i' == 5 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (0.005 * tot`pop')
						if `i' == 6 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (0.001 * tot`pop')
						if `i' == 7 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (0.0001 * tot`pop')
						if `i' == 9 cap gen avg`var'`i'`pop'99 = 1000 * sh`var'`i'`pop'99 * tt`var' / (0.9 * tot`pop')
						}
					}
				}
			}
		}	
saveold "$diroutput/pre62/pre62comp.dta", replace





