
*************************************************************************************
* created 10/2018, projection beyond $endyear	
* strategy: take the 2012 small file and assume distribution in 2017+ is like 2012
* 2017: blow up weights and incomes to be consistent with macro numbers from Piketty-Saez series
* 2018+: use the same ad-hoc methodology as in parameters
* recompute fedtax using taxsim
*************************************************************************************		
	
* global set old=1 if doing things the old way (pre-August 2020), old=0 for more sophisticated projection	using SOI tabls
global old=0
*global taxsim=0	
* global yr is the year for which we compute projected dataset (defined in runusdina)	
*foreach yr of numlist 2017/2019 {	
*global yr=`yr'
*global pufendyear = 2012
*global yr=2017

* need to grab population totals from parameters
*insheet using "programs/$parameters", clear names
import excel using "$root/DINA(Aggreg).xlsx", sheet(ParametersStata) clear  firstrow  
keep if yr==$yr
foreach var of varlist _all {
local `var'=`var'
}

* I defined two globals that will be used below
global tottaxunits `tottaxunits'
global totadults20 `totadults20'


*************************************************
* OLD PROJECTION (pre-August 2020)
*************************************************

* projection for 2017 uses the Piketty-Saez series
if $yr==2017 {


* old code: pre-August 2020
* we start from 2012 small file
	use $dirsmall/small2012.dta, clear
cap gen qdivinc=.8*divinc
	
* modifying year variables
replace year=$yr
replace flpdyr=$yr
		
* modifying dweght to match corresponding population totals
quietly sum agi [w=dweghttaxu]
local sumw=r(sum_w)*1e-8
display $tottaxunits/`sumw'
replace dweghttaxu=round(dweghttaxu*$tottaxunits/`sumw')
quietly sum agi [w=dweghttaxu]

gen adult=1
replace adult=2 if married==1
quietly sum adult [w=dweght]
local sumw=r(sum)*1e-8
display `sumw'
display $totadults20/`sumw'
replace dweght=round(dweght*$totadults20/`sumw')
sum adult [w=dweght]
local sumw=r(sum)*1e-8
display `sumw'
drop adult
* note that the fraction married is not going to be quite right nor is the full population (kids), nor fraction 65+

* modifying all income sources to match 2017 totals
* target values from 2017 Piketty-Saez (found in DINA(aggreg).xls, sheet DataIncome, cols. WN+
* note that AGI nominal growth from 2016 to 2017 was 7.0%, business income growth was 10.5%,
* net rents, royalties, fiduciary was 12.9%

* known totals (based on prelim 2017 stats, to be revised in Jan 2019 with complete CDW data)
* revised on August 2020 with published SOI tabs

local totagi=10917*1e+9
local totwaginc=7565*1e+9
local totpeninc=1003*1e+9
local totkginc= 846*1e+9
local totaginokg=(10917-846)*1e+9
local totagiadj= 162*1e+9
local totdivinc= 277*1e+9
local totintinc = 105*1e+9
local totbusinc = 1054*1e+9
local totfedtax = 1563*1e+9
local totuiinc = 24.34*1e+9

gen businc=scorinc+partinc+schcinc
gen aginokg=agi-kgagi

foreach var of varlist agi waginc peninc kginc agiadj divinc intinc fedtax uiinc businc aginokg {
	quietly sum `var' [w=dweght] if filer==1
	local sumw=r(sum)*1e-5
	* display `sumw'
	* display `tot`var''
	local gr`var'=`tot`var''/`sumw'
	* display `gr`var''
	replace `var'=`var'*`gr`var''
	quietly sum `var' [w=dweght]
	local sumw=r(sum)*1e-5
	* display `sumw'
	}
		
replace wages=waginc
replace wagincsec=wagincsec*`grwaginc'
replace penincnt=penincnt*`grpeninc'
replace penira=penira*`grpeninc'
replace intexm=intexm*`grintinc'
replace qdivinc=qdivinc*`grdivinc'
replace kgagi=kginc
replace kgincfull=kginc


* replace unknown components using agi without K gains
foreach var of varlist setax sey seysec income agicrr charit-studentded eictot-realestatetax ssinc ssincsec incomeps {
	replace `var'=`var'*`graginokg'
	}

* replace business components using businc
foreach var of varlist rentinc-partscorl {	
	replace `var'=`var'*`grbusinc'
	}

cap drop businc aginokg

* recompute variables
replace suminc=waginc+peninc+divinc+intinc+rentinc+estinc+rylinc+schcinc+scorinc+partinc 
replace othinc=income-suminc 

sort id
save $dirsmall/small$yr.dta, replace

* recompute fedtax using taxsim subroutine, fedtax$yr id saved in fedtax$yr.dta (set global $taxsim=0 if no need to recompute)
if $taxsim==1 do programs/taxsim.do
cap mkdir $dirsmall/taxsim
if $taxsim==0 use $dirsmall/taxsim/fedtax$yr.dta, clear

merge 1:1 id using $dirsmall/small$yr.dta

* renormalize fedtax, not clear whether taxsim is super accurate
sum fedtax* [w=dweght] if filer==1
sum fedtax* [w=dweght] if filer==1 & agi>=500000

replace fedtax2017=0 if filer==0
quietly sum fedtax2017 [w=dweght] if filer==1
local sumw=r(sum)*1e-5
quietly sum fedtax [w=dweght] if filer==1
local sumw2=r(sum)*1e-5
replace fedtax2017=fedtax2017*`sumw2'/`sumw'
sum fedtax* [w=dweght] if filer==1
replace fedtax=fedtax2017
drop _merge fedtax2017

order year dweght dweghttaxu filer id
sort id
save $dirsmall/small$yr.dta, replace


}
* end of year 2017, old code 


* simplified projection for years beyond 2017, extrapolate from small2017.dta previously constructed
// nominal GDP annual growth for 2018=5.3%, 2019=4.5%, 2020=4.1%, 2021=3.9%
// from DINA(aggreg).xls sheet Projections (at the back)
// population 20+ growth is .9% per year after 2017



* for 2018, need to re-use taxsim calculator

if $yr>=2018  {
	local prioryr=$yr-1
	use $dirsmall/small`prioryr'.dta, clear
	
* modifying year variables
replace year=$yr
replace flpdyr=$yr 	
	
* upgrade population weights (.9% growth per year after 2017)
	replace dweght=round(dweght*1.009)
	replace dweghttaxu=round(dweghttaxu*1.009)

* upgrade all income measures
	foreach var of varlist agi-othinc wagincsec ssincsec incomeps {	
	if $yr==2018 replace `var'=`var'*(1.053/1.009)
	if $yr==2019 replace `var'=`var'*(1.045/1.009)
	if $yr==2020 replace `var'=`var'*(1.041/1.009)
	if $yr==2021 replace `var'=`var'*(1.039/1.009)
	}
	
	sort id
	save $dirsmall/small$yr.dta, replace
	
	if $yr==2018 {
	* recompute fedtax using taxsim subroutine, fedtax$yr id saved in fedtax$yr.dta (set global $taxsim=0 if no need to recompute)
	if $taxsim==1 do programs/taxsim.do
	if $taxsim==0 use $dirsmall/taxsim/fedtax$yr.dta, clear
	merge 1:1 id using $dirsmall/small$yr.dta
	
	
	* total for fedtax2018 is reasonable, $112bn less than baseline
	sum fedtax* [w=dweght]
	gen fedtax2017=fedtax
	replace fedtax2018=0 if filer==0
	replace fedtax=fedtax2018
	*replace fedtax=min(fedtax,fedtax2018) if agi>400000
	sum fedtax* [w=dweght]
	sum fedtax* [w=dweght] if agi>=400000
	drop _merge fedtax2018 fedtax2017

}



order year dweght dweghttaxu filer id
sort id
save $dirsmall/small$yr.dta, replace

}


*****************************************************************************************************************
* August 2020: recompute the 2017+ small files here using SOI tabs by AGI bins for 2017 and 2018 (and uniform proj after)
*****************************************************************************************************************

if ($yr==2017 | $yr==2018) & $data==0 & $old==0 {

*if $yr==2012 import excel using "$root/rawdata/rawexcel/soipub2017.xls", sheet(tab${yr}prel) clear  firstrow 
*if $yr==2016 import excel using "$root/rawdata/rawexcel/soipub2017.xls", sheet(tab${yr}prel) clear  firstrow 
*if ($yr==2017 | $yr==2018) import excel using "$root/rawdata/rawexcel/soipub$yr.xls", sheet(tab$yr) clear  firstrow 

import excel using "$root/rawdata/rawexcel/soipub$yr.xls", sheet(tab$yr) clear  firstrow 
gen id=_n
sort id
replace agimax=1e+15 if agimax==.
rename agimax agibin
* compute percentiles corresponding to each bin
save $dirsmall/aggsoi$yr.dta, replace
* defining global $varsoi as the variable list of soi tab 
global varsoi0 "agi-ctcrefn"
global varsoi ""
foreach var of varlist $varsoi0 {
	global varsoi "$varsoi `var'"
	}
	
	
sum agi [w=dweght]
local agitot=r(sum)
local numtot=r(sum_w)
sum agi [w=dweght] if agi>0
local numtotp=r(sum_w)

* outfile the percentile list
matrix perc = J(19,1,0)
foreach j of numlist 1/19 {
   quietly sum perc if _n==`j'
   matrix perc[`j',1]=r(mean)
   }
   matrix list perc
  
* create the updated $yr small file starting from the $yr small file
use $dirsmall/small$yr.dta, clear
keep if filer==0
save $dirsmall/small${yr}nf.dta, replace

use $dirsmall/small$yr.dta, clear

keep if filer==1
* SOI tables can have person with both positive and negative partscor (while partscor in small is either>0 or <0)
replace partscorp=scorpinc+partpinc
replace partscorl=scorlinc+partlinc
gen partscorpold=partscorp
gen partscorlold=partscorl

* create the aggproj$yr.dta from the old projected 2017 data to merge by percentiles into 2017
* line up totals for returns
quietly sum agi [w=dweght] if agi>0
local numtotpold=r(sum_w)*1e-5
replace dweght=round(dweght*`numtotp'/`numtotpold') if agi>0
replace dweghttaxu=round(dweghttaxu*`numtotp'/`numtotpold') if agi>0
quietly sum agi [w=dweght] if agi>0
display `numtotpold'  " TRUE # FILERS " `numtotp' " REVISED # FILERS AGI>0  " r(sum_w)*1e-5

gen agibin=0
replace agibin=1 if agi<=0
cap drop perc
cumul agi [aw=dweght] if agi>0, gen(perc)

local num0=-1e+15
local j=0
foreach num of numlist 5000 10000 15000 20000 25000 30000 40000 50000 75000 100000 200000 500000 1000000 1500000 2000000 5000000 10000000 1e+15 {
	local j=`j'+1
	* replace agibin=`num' if agi>=`num0' & agi<`num'
	replace agibin=`num' if perc>=perc[`j',1] & perc<=perc[`j'+1,1]  
	local num0=`num'
}

save $dirsmall/small${yr}.dta, replace
tab agibin [iw=dweght] 
table agibin [iw=dweght], c(max agi)


keep agibin dweght year married xded xkids oldexm $varsoi filer
order filer dweght year married xded xkids oldexm $varsoi
keep if filer==1
drop filer
collapse (rawsum) dweght (mean) year married xded xkids oldexm $varsoi [aw=dweght], by(agibin)
replace dweght=round(dweght*1e-5)
sort agibin
gen id=_n
sort id
save $dirsmall/aggproj$yr.dta, replace


* compute the multipliers by income groups
use $dirsmall/aggsoi$yr.dta
append using $dirsmall/aggproj$yr.dta
keep year id agibin dweght $varsoi
foreach var of varlist $varsoi {
	replace `var'=`var'/`var'[_n+19] if year==$yr & id==id[_n+19]
	replace `var'=1 if (`var'<=0 | `var'[_n+19]==0) & year==$yr & id==id[_n+19]
	replace `var'=2 if `var'>=2 & year==$yr & id==id[_n+19]
	rename `var' `var'_m
	}
	
keep if _n<=19
replace item_m=1
drop id
sort agibin	

save $dirsmall/multsoi${yr}.dta, replace	


* readjust using these multipliers (code borrowed from aging)
	
use $dirsmall/small${yr}.dta, clear
sort agibin
merge m:1 agibin using $dirsmall/multsoi${yr}.dta
drop if _merge!=3
drop _merge

*replace dweght=dweght*dweght_m
foreach var of varlist $varsoi {
	replace `var'=`var'*`var'_m 
	}
		
sum kginc [w=dweght]
local tot=r(sum)
replace kginc=max(-3000,kginc)
sum kginc [w=dweght]
local corr=`tot'/r(sum)
replace kginc=kginc*`corr'
replace kginc=max(-3000,kginc)

replace year=round(year)
drop agibin *_m
replace dweght=round(dweght)

/*
* testing, works pretty well for AGI shares
local var "agi"
cap drop rank
cumul `var' [w=dweght] if `var'>=0, gen(rank)
sum `var' [w=dweght] if rank!=.
local tot=r(sum)
sum `var' [w=dweght] if rank>=.99
display "Top 1% share = " r(sum)/`tot'
*/

* rebuild all the small variables as in pufonline, maybe use a subroutine here to avoid repeating program 
replace ttltxp=realestatetax+statetax
sum schcinc [w=dweght]
replace schcinc=schcincp-schcincl 
sum schcinc [w=dweght]
replace rentinc=rentincp-rentincl 

replace partscor=partscorp-partscorl 
replace scorpinc=max(0,scorpinc*partscorp/partscorpold)
replace scorlinc=max(0,scorlinc*partscorl/partscorlold)
replace scorinc=scorpinc-scorlinc
replace partpinc=max(0,partpinc*partscorp/partscorpold)
replace partlinc=max(0,partlinc*partscorl/partscorlold)
replace partinc=partpinc-partlinc

replace scorpinc2=max(0,scorinc)
replace partpinc2=max(0,partinc)
replace scorlinc2=max(0,-scorinc)
replace partlinc2=max(0,-partinc)
replace partscorp=max(0,partscor)
replace partscorl=max(0,-partscor)

replace wages=waginc
replace suminc=waginc+peninc+divinc+intinc+rentinc+estinc+rylinc+schcinc+scorinc+partinc 
replace othinc=income-suminc

foreach var of varlist partpnp partpp partlnp partlp scorpnp scorpp scorlnp scorlp othinc_imp {
	replace `var'=0
	}
drop partscorpold partscorlold 

cap gen taxunits=$tottaxunits
cap gen adults20=$totadults20	
	
* ordering the variables as in original small$yr files (program will fail if $vartot not defined by going through build_small earlier)
global vartot "year id state dweght flpdyr taxunits adults20 married marriedsep single head xded dependent xkids item oldexm oldexf female femalesec age agesec agi setax sey seysec wages waginc peninc penincnt penira divinc qdivinc intinc intexm rentinc rentincp rentincl rylinc estinc othinc_imp schcinc schcincp schcincl partpinc partlinc scorpinc scorlinc partpnp partpp partlnp partlp scorpnp scorpp scorlnp scorlp scorinc partinc partscor scorpinc2 scorlinc2 partpinc2 partlinc2 partscorp partscorl kgagi kgincfull kgagid kginc agiadj income agicrr charit itemded intded mortded intdedoth mortrental studentded fedtax eictot eicrefn ctctot ctcrefn statetax ttltxp realestatetax uiinc ssinc suminc othinc oldmar"
   
order $vartot

append using "$dirsmall/small${yr}nf.dta"
replace taxunits=$tottaxunits
replace adults20=$totadults20

sort id


* modifying dweght, dweghttaxu in non-filer dataset to match corresponding population totals
quietly sum agi [w=dweghttaxu]
local sumw=r(sum_w)*1e-8
local gap=$tottaxunits-`sumw'
quietly sum agi [w=dweghttaxu] if filer==0
local sumwnf=r(sum_w)*1e-8
replace dweghttaxu=round(dweghttaxu*(`sumwnf'+`gap')/`sumwnf') if filer==0
quietly sum agi taxunits [w=dweghttaxu]
quietly sum agi [w=dweghttaxu] if filer==0

gen adult=1
replace adult=2 if married==1
quietly sum adult [w=dweght]
local sumw=r(sum)*1e-8
display `sumw' " " $totadults20
local gap=$totadults20-`sumw'
quietly sum agi [w=dweght] if filer==0 & married==0
local sumwnf=r(sum_w)*1e-8
replace dweght=round(dweght*(`sumwnf'+`gap')/`sumwnf') if filer==0 & married==0
quietly sum adult [w=dweght]
local sumw=r(sum)*1e-8
display `sumw'
quietly sum agi [w=dweght] if filer==0 & married==0
drop adult

*save "$dirsmall/small${yr}new.dta", replace
save $dirsmall/small${yr}.dta, replace

		
	}
	* end of 2017 and 2018 tabulation loop
	
* recompute 2019+ using latest new files	
if $yr>2018 & $old==0 {
	local prioryr=$yr-1
	use $dirsmall/small`prioryr'.dta, clear
	
* modifying year variables
replace year=$yr
replace flpdyr=$yr	
	
* upgrade population weights (.9% growth per year after 2018)
	replace dweght=round(dweght*1.009)
	replace dweghttaxu=round(dweghttaxu*1.009)

* upgrade all income measures
	foreach var of varlist agi-othinc wagincsec ssincsec incomeps {	
	if $yr==2018 replace `var'=`var'*(1.053/1.009)
	if $yr==2019 replace `var'=`var'*(1.045/1.009)
	if $yr==2020 replace `var'=`var'*(1.041/1.009)
	if $yr==2021 replace `var'=`var'*(1.039/1.009)
	}
	
	sort id
	*save $dirsmall/small${yr}new.dta, replace
	save $dirsmall/small${yr}.dta, replace	
	drop perc	
	
	}	
	* end of 2019+ projection




/* OLD: USE THIS ONLY IF WANT TO REUSE PRE-AUG 2020 SMALL FILES
* rename datasets so that new small file becomes standard and old file stored in small${yr}old
foreach yr of numlist 2017/2019 {	
if $old==0 {
use $dirsmall/small`yr'.dta, clear
save $dirsmall/small`yr'old.dta, replace
use $dirsmall/small`yr'new.dta, clear
save $dirsmall/small`yr'.dta, replace
	}	
	}

* reverting to old datasets	
foreach yr of numlist 2012 2016 2017/2019 {	
if $old==1 {
use $dirsmall/small`yr'.dta, clear
save $dirsmall/small`yr'new.dta, replace
use $dirsmall/small`yr'old.dta, clear
save $dirsmall/small`yr'.dta, replace
	}	
	}
*/	
	
	
