* Console for US DINA: defines paths & runs programs that creates databases & generate all results from raw files

clear
clear matrix
clear mata
set type double
cap set maxvar 30000

*******************************************************************************
* CHOOSE DATA SOURCE AND YEARS
*******************************************************************************

quietly {
// data = 0 for external data (PUF), data = 1 for internal data (INSOLE)
	global data = 0
	if $data == 0 set matsize 11000

//  * online=0 for internal or PUF external, online = 1 for data to be posted online
	global online = 1
	* if $data == 1 global online = 0 

//   calibweight=1 for PUF online using calibrated weights to match internal stats (otherwise set to zero), not used anymore
	global calibweight = 0

// Select years  
	* endyear is the last year internally, pufendyear is that last year of PUF external, lastyear is last projected year
	global lastyear = 2019
	global pufendyear = 2012
	if $data == 0 global endyear = 2016
	if $data == 1 global endyear = 2016
	if $data == 1 global lastyear = $endyear


	* databankyear is the last year of databankyear (for wages earnings splits)
	global databankyear = 2015
	* cpsendyear is the last year of cps income available, survey is nominally the march year cpsendyear+1
	* global cpsendyear = 2016
	global years "1962 1964 1966/$lastyear"
	* global years "2010/2019"
	 
		numlist "$years"
		local fullyears = "`r(numlist)'"
		local nbyears : list sizeof local(fullyears)
}

*******************************************************************************
* DEFINE PATHS
*******************************************************************************

quietly {
// Data paths
		cap cd		 "/Users/gzucman/Dropbox/SaezZucman2014/usdina"
		cap cd		 "/Users/zucman/Dropbox/SaezZucman2014/usdina"
  		cap cd 		 "/Users/manu/Dropbox/SaezZucman2014/usdina"
		cap cd       "c:/saez/usdina"
		cap cd       "home/8rknb/usdina"
		cap cd       "bod/OTA7/8rknb/usdina"
		global root "`c(pwd)'"
		
					global  dirirs 		 "$root/rawdata/puf"
					global  dirirsint 	 "$root/rawdata/irsinternal"
					global  dircps 		 "$root/rawdata/cps"
					global  dirscfraw 	 "$root/rawdata/scf"
					global  direxcel	 "$root/rawdata/rawexcel"
					global  diroutput	 "$root/output"
					global  dirmatrix 	 "$root/output/matrices"
					global  dircollapse  "$root/output/small/collapse"
					global  dirsmall	 "$root/output/small"
    if $online==1   global  dirsmall	 "$root/output/small/online"
					global  dirusdina	 "$root/output/dinafiles"
	if $online==1   global  dirusdina	 "$root/output/dinafiles/online"
					global  dirnonfilers "$root/output/cpstaxunit"
					global  dirscfclean	 "$root/output/scfclean"
					global  dirprograms	 "$root/programs"
					global  parameters 	 "$root/programs/parameters.xlsx"					
					global 	aggregate    "$root/DINA(Aggreg).xlsx"
					global 	distrib 	 "$root/DINA(Distrib).xlsx"
	if $data==0 	global 	diroutsheet  "$root/output/ToExcel"
	if $online==1 	global 	diroutsheet  "$root/output/ToExcelonline"
	if $online==1 & $calibweight==1 	global 	diroutsheet  "$root/output/ToExcelonlinecal"
	if $data==1 	global 	diroutsheet  "$root/output/ToExcelInternal"

// Ado file directory
	global ado_dir "$dirprograms/ado"
	sysdir set PERSONAL "$ado_dir"
}


*******************************************************************************
* EXCECUTE DO FILES
*******************************************************************************

cd "$root"


*************************************************************
*** Part 1: External macro data: Aggregates, SCF, CPS
*************************************************************



// Update aggregate data in DINA.xlsx. Last run: December 11, 2015 [takes about 15 min to run, mostly due to NIPA part]
*	if $data == 0 do "programs/scrap_macro.do"


// Build SCF surveys & constructs SCF matrices used for imputations (currently up to SCF 2013, should update to SCF 2016)
	* if $data == 0 do "programs/use_scf.do"
	
// Build CPS surveys & construct CPS matrices used for imputations
    *	if $data == 0 do "programs/use_cps.do"



*************************************************************
*** Part 2: Internal IRS data work
*************************************************************

/*

// Use INSOLE raw files to create PUF equivalent xYYYY.dta files (redoes only $yearmin to $endyear)   
	global yearmin=1979
	* if $data == 1 do "programs/build_xdata.do"
	
	 * added 4/2019: can now use stata program to grab CDW variables in IRS STATA server, bypassing the need to use SAS
	 if $root == "home/8rknb/usdina" & $data==1 do "programs/build_cdw.do"

// Add demographic and databank variables to xYYYY.dta files (redoes only $yearmin to $endyear)
	* if $data == 1 do "programs/build_xfile.do"
	
// Creates aggregate record $10m+ internally ($data=1) and creates the synthetic record in $dirirsint/topstat/synthrec`yr'.dta to append to xfiles externally ($data=0) for 1996-2010 (no need in 2011+ with aggregate records)
	* do "programs/aggrecord.do"
	
// Split wages by computing variable share_f [stored it in work`yr'.dta for now with id=_n sorting to match small later on]
    * set global firstyear=1979 to redo all years, global firstyear=$endyear to do latest year only (faster)
	global firstyear=$endyear	
	* if $online==0 do "programs/sharefbuild"
	* need to bring back internal files matrices/wagmat/wagspintYYYY.xls sespintYYYY.xls etc. to run externally for addsharef.do

// matrix to store results of various tests for impute.do (monitor) and nonfilerappend.do (weights)
	matrix monitor=J(40,25,.)
	matrix weights = J(60,26,.)

*/

*************************************************************
*** Part 3: Build small files and DINA files
*************************************************************

***************************************
*** Part 3A: Build small files 
***************************************

/*

foreach yr of numlist $years {
	global yr=`yr'


	
// building small files for all years up to $endyear (last year internal micro data available)
	if $yr<=$endyear { 		 
 
	// Build small files from raw NBER PUF micro-files (externaly, year beyond pufendyear are built by aging small$pufendyear using internal tabs)
		 if $yr<=$pufendyear | $data==1  do "programs/build_small.do"
		 * aging the PUF using internal INSOLE tabulations, need to bring back internal files small/agingtableYYYY.dta
		 if $yr>$pufendyear & $data==0  do "programs/aging.do"
		  
	// Build disclosure proof small files for online disclosure, added 5/2017
	    * global group5=0 if grouping of 5 has to be redone (very time consuming), group5=1 if we re-use older grouping auxfull$yr.dta files
	    global group5=1
		if $online==1 & $data==0 do "programs/onlinedata.do"

	// Adding share_f (share female) for earnings split in small files
		 do "programs/addsharef.do"
		
	// Impute age, gender, using internal tabulations 1979+, and gender imputation 1962-1978
		* need to bring back internal files small/collapse/xmarriedcoarseYYYY.dta and xsinglecoarseYYYY.dta to run externally
		do "programs/impute.do"
		
	// Append non-filers to small data with correct population weighting
		do "programs/nonfilerappend.do"
	}


	
	
// for years past $endyear (last year internal micro data available) we use a projection method based on small2012.dta file
// global taxsim is set to 1 if need to compute taxes using taxsim, set to 0 if taxes already computed	
// issue is that taxsim not available inside IRS
// August 2020 modified projection to use SOI published tabs for 2017 and 2018 to improve accuracy
	global taxsim=0
	if $yr>$endyear & $data==0 do "programs/projection.do"
	
}


* Sept 2020: add passive/non-passive S corp and partnership data after $pufendyear
	foreach yr of numlist $pufendyear/$lastyear {
		global yr=`yr'
		if ($yr>$pufendyear & $data==0) | ($yr>$endyear & $data==1) do "programs/addpassive.do"
  	}
*/
	
	
***************************************
*** Part 3B: Build DINA files
***************************************



* Creates and saves DINA micro-files at the individual level
	foreach yr of numlist $years {
		global yr=`yr'
		do "programs/build_usdina"
  	}


* Fix fiscal/pre-tax income ratio for top 400
   	 do "programs/top400.do"


// Testing calibrated weights from Thomas Blanchet (need to get 2016 weights)
   * if $online==1 & $yr<2016 do "programs/weight_usdina"	
	



*************************************************************
*** Part 4: Outsheet statistics post 1962
*************************************************************


// Outsheet DINA results, set global calibweight=1 if using calibrated weights in online files
	 do "programs/outsheet_dina"

// Put all Excel outsheet into single Excel file
	* if $data==0 do "programs/export-to-excel"	 
	 
// Distribution of wealth by AGI
 	* do "programs/wealth-by-agi"

// CPS summary statistics and comparisons with DINA
    * do "programs/stats_cps"


	
*************************************************************
*** Part 5: Pre-1962 computations
*************************************************************
* WARNING: needs to have DinaDistrib.xlsx saved using Excel 2011 before running export do files below
* If saved using Excel 2016, then export excel destroys the formatting of the Excel file
* https://www.statalist.org/forums/forum/general-stata-discussion/general/1353551-putexcel-error-message-with-office-2016-for-mac


//Pre-62
	 global source = 0 // 0 when external data, 1 when internal data
     do "programs/pre62"

// Export to Excel DINA(Distrib)
	  do "programs/export"    	

// Export tax rates + compo by pre-tax income group since 1913 to Excel DINA(Distrib)
	  do "programs/taxrates"  


***************************************
*** Part 6: Various computations and simulations
***************************************

// Quick computations of top wealth and pre-tax income shares with components
	 do "programs/topshares.do"

// Wealth tax simulations in SCF (2016)
	* do "programs/scftax.do"

// Capital share in top 1%
	* do "programs/kl_business"
	* do "programs/kshare.do"




* XX TO DO AT IRS
* add qdiv once access to IRS to small files
* try getting roth IRA distribution internally
* add more variables in tabulated data 2013+ namely scorincp, scorincl, schcincl schcincp, rentincp, rentincl, and passive, nonpassive (then remove addpassive) 

